package app;

import java.awt.*;
import java.awt.event.*;
import java.io.IOException;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.time.format.DateTimeParseException;
import java.time.format.FormatStyle;
import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import javax.swing.*;

public class GUI extends JFrame {

    private static final long serialVersionUID = 2660174081832289605L;

    private ResourceBundle bundle;
    private String[] locales = { "de_DE", "en" };
    private JComboBox<String> comboBox = new JComboBox<>(locales);
    private JTextField firstNameInput = new JTextField("Angela");
    private JTextField nameInput = new JTextField("Merkel");
    private JTextField birthdayInput = new JTextField("05.07.1958");
    private JLabel kundeLbl;
    private JButton loadBtn;
    private JButton saveBtn;
    private JLabel firstNameLbl;
    private JLabel nameLbl;
    private JLabel birthdayLbl;

    public GUI() {
        super("Internationalisierung und Datumsverarbeitung");
        this.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
        this.setSize(500, 200);
        drawGUI("de_DE");
    }

    public void drawGUI(String locale) {
        try {
            bundle = ResourceBundle.getBundle("locale_" + locale);
        } catch (MissingResourceException e) {
            System.err.println(e);
        }
        kundeLbl = new JLabel(bundle.getString("Headline"));
        loadBtn = new JButton(bundle.getString("LoadBtn"));
        saveBtn = new JButton(bundle.getString("SaveBtn"));
        firstNameLbl = new JLabel(bundle.getString("FirstName"));
        nameLbl = new JLabel(bundle.getString("Name"));
        birthdayLbl = new JLabel(bundle.getString("Birthday"));

        Container container = this.getContentPane();
        JFrame parent = this;
        container.setLayout(new GridLayout(6, 2));
        container.add(new JLabel(""));
        container.add(new ComboBoxPanel(this));
        kundeLbl.setFont(new Font(kundeLbl.getFont().getFamily(), Font.BOLD, 24));
        container.add(kundeLbl);
        container.add(new JLabel(""));
        container.add(firstNameLbl);
        container.add(firstNameInput);
        container.add(nameLbl);
        container.add(nameInput);
        container.add(birthdayLbl);
        container.add(birthdayInput);
        container.add(loadBtn);
        container.add(saveBtn);
        saveBtn.addActionListener(e -> {
            try {
                Locale currentLocale;
                if (comboBox.getSelectedItem().toString() == "de_DE")
                    currentLocale = Locale.GERMAN;
                else
                    currentLocale = Locale.ENGLISH;
                DateTimeFormatter formatter = DateTimeFormatter.ofLocalizedDate(FormatStyle.MEDIUM)
                        .withLocale(currentLocale);
                LocalDate birthday = LocalDate.parse(birthdayInput.getText(), formatter);
                Kunde kunde = new Kunde(firstNameInput.getText(), nameInput.getText(), birthday);
                Datenhaltung.speichereKunde(kunde, currentLocale);
                JOptionPane.showMessageDialog(parent, bundle.getString("SaveDone"), bundle.getString("Message"),
                        JOptionPane.INFORMATION_MESSAGE);
            } catch (IOException ex) {
                JOptionPane.showMessageDialog(parent, bundle.getString("IOException"), bundle.getString("Error"),
                        JOptionPane.ERROR_MESSAGE);
            } catch (DateTimeParseException ex) {
                JOptionPane.showMessageDialog(parent, bundle.getString("DateTimeParseException"),
                        bundle.getString("Error"), JOptionPane.ERROR_MESSAGE);
            }
        });
        loadBtn.addActionListener(e -> {
            try {
                Locale currentLocale;
                if (comboBox.getSelectedItem().toString() == "de_DE")
                    currentLocale = Locale.GERMAN;
                else
                    currentLocale = Locale.ENGLISH;
                DateTimeFormatter formatter = DateTimeFormatter.ofLocalizedDate(FormatStyle.MEDIUM)
                        .withLocale(currentLocale);
                Kunde kunde = Datenhaltung.ladeKunde(currentLocale);
                firstNameInput.setText(kunde.getFirstName());
                nameInput.setText(kunde.getName());
                birthdayInput.setText(kunde.getBirthday().format(formatter));
            } catch (IOException ex) {
                JOptionPane.showMessageDialog(parent, bundle.getString("IOException"), bundle.getString("Error"),
                        JOptionPane.ERROR_MESSAGE);
            }
        });
    }

    private class ComboBoxPanel extends JPanel {
        private static final long serialVersionUID = -125611113722513442L;

        ComboBoxPanel(GUI parent) {
            this.setLayout(new FlowLayout(FlowLayout.RIGHT));
            this.add(comboBox);
            comboBox.addActionListener(e -> {
                System.out.println(comboBox.getSelectedItem());
                try {
                    bundle = ResourceBundle.getBundle("locale_" + comboBox.getSelectedItem());
                } catch (MissingResourceException ex) {
                    System.err.println(e);
                }
                kundeLbl.setText(bundle.getString("Headline"));
                loadBtn.setText(bundle.getString("LoadBtn"));
                saveBtn.setText(bundle.getString("SaveBtn"));
                firstNameLbl.setText(bundle.getString("FirstName"));
                nameLbl.setText(bundle.getString("Name"));
                birthdayLbl.setText(bundle.getString("Birthday"));
                parent.repaint();
            });
        }
    }
}